@@ -2,9 +2,9 @@
 scripts.
 
 :author:    Logilab
-:copyright: 2000-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2000-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: General Public License version 2 - http://www.gnu.org/licenses
+:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
 __docformat__ = "restructuredtext en"
 
@@ -258,12 +258,29 @@ class ProgressBar(object):
     """A simple text progression bar."""
 
     def __init__(self, nbops, size=20, stream=sys.stdout, title=''):
-        self._fstr = '\r%s[%%-%ss]' % (title, int(size))
+        if title:
+            self._fstr = '\r%s [%%-%ss]' % (title, int(size))
+        else:
+            self._fstr = '\r[%%-%ss]' % int(size)
         self._stream = stream
         self._total = nbops
         self._size = size
         self._current = 0
         self._progress = 0
+        self._current_text = None
+        self._last_text_write_size = 0
+
+    def _get_text(self):
+        return self._current_text
+
+    def _set_text(self, text=None):
+        self._current_text = text
+        self.refresh()
+
+    def _del_text(self):
+        self.text = None
+
+    text = property(_get_text, _set_text, _del_text)
 
     def update(self):
         """Update the progression bar."""
@@ -276,6 +293,14 @@ class ProgressBar(object):
     def refresh(self):
         """Refresh the progression bar display."""
         self._stream.write(self._fstr % ('.' * min(self._progress, self._size)) )
+        draw_text = False
+        if self._last_text_write_size or self._current_text:
+            template = ' %%-%is' % (self._last_text_write_size)
+            text = self._current_text
+            if text is None:
+                text = ''
+            self._stream.write(template % text)
+            self._last_text_write_size = len(text.rstrip())
         self._stream.flush()
 
 from logilab.common.deprecation import deprecated
