@@ -2,7 +2,7 @@
 """
 
 from logilab.common.testlib import TestCase, unittest_main
-from logilab.common.decorators import monkeypatch
+from logilab.common.decorators import monkeypatch, cached
 
 class DecoratorsTC(TestCase):
 
@@ -26,6 +26,20 @@ class DecoratorsTC(TestCase):
         inst = MyClass()
         self.assertEquals(inst.foo(4), 16)
 
+    def test_cached_preserves_docstrings(self):
+        class Foo(object):
+            @cached
+            def foo(self):
+                """ what's up doc ? """
+            def bar(self, zogzog):
+                """ what's up doc ? """
+            bar = cached(bar, 1)
+            @cached
+            def quux(self, zogzog):
+                """ what's up doc ? """
+        self.assertEquals(Foo.foo.__doc__, """ what's up doc ? """)
+        self.assertEquals(Foo.bar.__doc__, """ what's up doc ? """)
+        self.assertEquals(Foo.quux.__doc__, """ what's up doc ? """)
 
 if __name__ == '__main__':
     unittest_main()
