@@ -3,7 +3,7 @@
 :author:    Logilab
 :copyright: 2003-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: General Public License version 2 - http://www.gnu.org/licenses
+:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 
 :group text formatting: normalize_text, normalize_paragraph, pretty_match,\
 unquote, colorize_ansi
@@ -243,11 +243,11 @@ __UNITS_URE = r'[a-zA-Z]+'
 _VALUE_RE = re.compile(r'(?P<value>%s)(?P<unit>%s)?'%(__VALUE_URE,__UNITS_URE))
 
 BYTE_UNITS = {
-     "B": 1,
-    "KB": 1024,
-    "MB": 1024 ** 2,
-    "GB": 1024 ** 3,
-    "TB": 1024 ** 4,
+    "b": 1,
+    "kb": 1024,
+    "mb": 1024 ** 2,
+    "gb": 1024 ** 3,
+    "tb": 1024 ** 4,
 }
 
 TIME_UNITS = {
@@ -289,7 +289,11 @@ def apply_units( string, units, inter=None, final=float, blank_reg=_BLANK_RE,
         lit, unit = dic["value"], dic.get("unit")
         value = inter(lit)
         if unit is not None:
-            value *= units[unit]
+            try:
+                value *= units[unit.lower()]
+            except KeyError:
+                raise KeyError('invalid unit %s. valid units are %s' %
+                               (unit, units.keys()))
         values.append(value)
     return final(sum(values))
 
